package cc.bnblogs.controller;

import cc.bnblogs.pojo.User;
import cc.bnblogs.utils.LoginCacheUtils;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.thymeleaf.util.StringUtils;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;
import java.util.*;

/**
 * @description: 用户登录逻辑
 * @author: zfp@bnblogs.cc
 * @date: 2023/3/12 15:53
 */
@Controller
@RequestMapping("/login")
public class LoginController {

    // 模拟用户数据
    private static Set<User> dbUsers;

    static {
        dbUsers = new HashSet<>();
        dbUsers.add(new User(1,"user1","123456"));
        dbUsers.add(new User(2,"user2","123456"));
        dbUsers.add(new User(3,"user3","123456"));
        dbUsers.add(new User(4,"user4","123456"));
        dbUsers.add(new User(5,"user5","123456"));
        dbUsers.add(new User(6,"user6","123456"));
    }
    @PostMapping
    public String doLogin(User user, HttpSession httpSession, HttpServletResponse httpServletResponse) {
        String target = (String) httpSession.getAttribute("target");

        // 模拟数据库根据用户名和密码查询该用户是否存在
        Optional<User> first = dbUsers.stream().filter(dbUser -> dbUser.getUsername().equals(user.getUsername()) &&
                dbUser.getPassword().equals(user.getPassword())).findFirst();

        // 如果该用户存在
        if (first.isPresent()) {
            // 保存用户登录信息
            // 生成一个token作为key
            String token = UUID.randomUUID().toString();
            // 将token存入cookie
            Cookie cookie = new Cookie("TOKEN",token);
            // 设置相同的域
            cookie.setDomain("codeshop.com");
            // 将cookie通过响应返回
            httpServletResponse.addCookie(cookie);

            LoginCacheUtils.loginUser.put(token,first.get());
        }
        else {
            // 返回登录失败界面，可选择重新登录
            httpSession.setAttribute("msg","用户名或密码错误");
            return "login";
        }
        // 重定向到登录前的地址
        return "redirect:" + target;
    }

    /**
     * 根据请求中的token决定是否返回用户数据
     * @param token 请求方提供访问数据的token
     * @return 返回响应结果
     */
    @GetMapping("info")
    @ResponseBody
    public ResponseEntity<User> getUserInfo(String token) {
        if (!StringUtils.isEmpty(token)) {
            User user = LoginCacheUtils.loginUser.get(token);
            return ResponseEntity.ok(user);
        } else {
            return new ResponseEntity<>(null, HttpStatus.BAD_REQUEST);
        }
    }
}
