package cc.bnblogs.controller;

import cc.bnblogs.pojo.User;
import cc.bnblogs.utils.LoginCacheUtils;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.CookieValue;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.thymeleaf.util.StringUtils;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

/**
 * @description: 页面跳转逻辑
 * @author: zfp@bnblogs.cc
 * @date: 2023/3/12 15:55
 */
@Controller
@RequestMapping("/view")

public class ViewController {
    @GetMapping("/login")
    public String toLogin(@RequestParam(required = false,defaultValue = "") String target,
                          HttpSession httpSession,
                          @CookieValue(required = false, value = "TOKEN") Cookie cookie) {
        if (StringUtils.isEmpty(target)) {
            target = "http://www.codeshop.com:8082/view/index/";
        }

        // 如果用户已经成功登录，则不需要重复登录,直接重定向到页面
        // 从token中获取到用户信息
        if (cookie!=null) {
            String token = cookie.getValue();
            User user = LoginCacheUtils.loginUser.get(token);
            if (user != null) {
                return "redirect:" + target;
            }
        }

        // todo: 注意这里没有做地址校验
        httpSession.setAttribute("target",target);
        return "login";
    }

    /**
     *退出账户，将cookie设置为已过期
     *删除已登录的用户
     */
    @GetMapping("/logout")
    public String loginOut(@CookieValue(value = "TOKEN") Cookie cookie, HttpServletResponse response, String target) {
        cookie.setMaxAge(0);
        LoginCacheUtils.loginUser.remove(cookie.getValue());
        response.addCookie(cookie);
        return "redirect:" + target;
    }
}
